==> igniteui-angular-charts-18.2.0.tgz: package/esm2015/lib/ScatterPolylineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { StyleSelector } from "./StyleSelector";
import { DependencyProperty } from "igniteui-angular-core";
import { Style } from "igniteui-angular-core";
import { markType, markDep, typeCast } from "igniteui-angular-core";
import { ShapeSeriesViewBase } from "./ShapeSeriesViewBase";
import { ChartSelection } from "./ChartSelection";
import { List$1 } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { Defaults } from "./Defaults";
import { Path } from "igniteui-angular-core";
import { stringIsNullOrEmpty } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ScatterPolylineSeries = /*@__PURE__*/ (() => {
    class ScatterPolylineSeries extends ShapeSeriesBase {
        constructor() {
            super();
            this.ab = ScatterPolylineSeries.$;
        }
        bj() {
            return new ScatterPolylineSeries();
        }
        get_fr() {
            return true;
        }
        cs() {
            return new ScatterPolylineSeriesView(this);
        }
        get_x0() {
            return false;
        }
        q1(a) {
            super.q1(a);
            this.z7 = a;
        }
        get_x6() {
            return false;
        }
        q9(a, b, c, d) {
            super.q9(a, b, c, d);
            switch (b) {
                case ScatterPolylineSeries.$$p[0]:
                    this.z7.cy(this.aad);
                    this.rr(false);
                    this.ql();
                    break;
                case ScatterPolylineSeries.$$p[1]:
                    this.z7.cz(this.z8);
                    this.rr(false);
                    this.ql();
                    break;
            }
        }
        zn(a) {
            let b = a;
            b.cy(this.aad);
            b.cz(this.z8);
            super.zn(a);
        }
        a2(a, b) {
            let c = this.z7.c3(a, b, true);
            if (c != null) {
                return c.dataContext;
            }
            return super.a2(a, b);
        }
        ak(a, b) {
            let c = new List$1(ChartSelection.$, 0);
            this.p4(a, c, b);
            return c.toArray();
        }
        p4(a, b, c) {
            this.zf(a, b, c);
        }
    }
    ScatterPolylineSeries.$t = markType(ScatterPolylineSeries, 'ScatterPolylineSeries', ShapeSeriesBase.$);
    ScatterPolylineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:aad:aab', [Style.$, null], 'ShapeStyleSelector:z8:aac', [StyleSelector.$, null]]);
    return ScatterPolylineSeries;
})();
/**
 * @hidden
 */
export let ScatterPolylineSeriesView = /*@__PURE__*/ (() => {
    class ScatterPolylineSeriesView extends ShapeSeriesViewBase {
        constructor(a) {
            super(a);
        }
        au() {
            super.au();
            if (!this.q) {
                this.b6.jp = Defaults.aa;
            }
        }
        c5(a, b) {
            return this.c6(a, b, false);
        }
        cm(a, b, c) {
            super.cm(a, b, c);
            ShapeSeriesViewBase.cl(this, a, b);
        }
        ck(a, b) {
            let c = typeCast(Path.$, a);
            if (c == null) {
                return;
            }
            c.an = b;
        }
        ac(a) {
            let b = super.ac(a);
            b._fill = null;
            return b;
        }
        ab(a) {
            let b = super.ab(a);
            b._fill = null;
            return b;
        }
        cb(a) {
            return a.width >= this.b6.yn || a.height >= this.b6.yn;
        }
        getDefaultTooltipTemplate() {
            let a = "<div class='ui-chart-default-tooltip-content'><span";
            let b = this.e.ba.a$u(this.e);
            if (!stringIsNullOrEmpty(b)) {
                a += " style='color:" + b + "'";
            }
            a += ">" + this.b6.title + "</span><br/>";
            a += "</div>";
            return a;
        }
    }
    ScatterPolylineSeriesView.$t = markType(ScatterPolylineSeriesView, 'ScatterPolylineSeriesView', ShapeSeriesViewBase.$);
    return ScatterPolylineSeriesView;
})();

==> igniteui-angular-charts-20.0.0.tgz: package/esm2015/lib/ScatterPolylineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { StyleSelector } from "./StyleSelector";
import { DependencyProperty } from "igniteui-angular-core";
import { Style } from "igniteui-angular-core";
import { markType, markDep, typeCast } from "igniteui-angular-core";
import { ShapeSeriesViewBase } from "./ShapeSeriesViewBase";
import { ChartSelection } from "./ChartSelection";
import { List$1 } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { Defaults } from "./Defaults";
import { Path } from "igniteui-angular-core";
import { stringIsNullOrEmpty } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ScatterPolylineSeries = /*@__PURE__*/ (() => {
    class ScatterPolylineSeries extends ShapeSeriesBase {
        constructor() {
            super();
            this.ab = ScatterPolylineSeries.$;
        }
        bk() {
            return new ScatterPolylineSeries();
        }
        get_fs() {
            return true;
        }
        ct() {
            return new ScatterPolylineSeriesView(this);
        }
        get_x5() {
            return false;
        }
        q3(a) {
            super.q3(a);
            this.aac = a;
        }
        get_yb() {
            return false;
        }
        rc(a, b, c, d) {
            super.rc(a, b, c, d);
            switch (b) {
                case ScatterPolylineSeries.$$p[0]:
                    this.aac.db(this.aai);
                    this.ru(false);
                    this.qn();
                    break;
                case ScatterPolylineSeries.$$p[1]:
                    this.aac.dc(this.aad);
                    this.ru(false);
                    this.qn();
                    break;
            }
        }
        zs(a) {
            let b = a;
            b.db(this.aai);
            b.dc(this.aad);
            super.zs(a);
        }
        a2(a, b) {
            let c = this.aac.dg(a, b, true);
            if (c != null) {
                return c.dataContext;
            }
            return super.a2(a, b);
        }
        ak(a, b) {
            let c = new List$1(ChartSelection.$, 0);
            this.p6(a, c, b);
            return c.toArray();
        }
        p6(a, b, c) {
            this.zk(a, b, c);
        }
    }
    ScatterPolylineSeries.$t = markType(ScatterPolylineSeries, 'ScatterPolylineSeries', ShapeSeriesBase.$);
    ScatterPolylineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:aai:aag', [Style.$, null], 'ShapeStyleSelector:aad:aah', [StyleSelector.$, null]]);
    return ScatterPolylineSeries;
})();
/**
 * @hidden
 */
export let ScatterPolylineSeriesView = /*@__PURE__*/ (() => {
    class ScatterPolylineSeriesView extends ShapeSeriesViewBase {
        constructor(a) {
            super(a);
        }
        a4() {
            super.a4();
            if (!this.t) {
                this.cj.jq = Defaults.an;
            }
        }
        di(a, b) {
            return this.dj(a, b, false);
        }
        cz(a, b, c) {
            super.cz(a, b, c);
            ShapeSeriesViewBase.cy(this, a, b);
        }
        cx(a, b) {
            let c = typeCast(Path.$, a);
            if (c == null) {
                return;
            }
            c.an = b;
        }
        ak(a) {
            let b = super.ak(a);
            b._fill = null;
            return b;
        }
        aj(a) {
            let b = super.aj(a);
            b._fill = null;
            return b;
        }
        co(a) {
            return a.width >= this.cj.ys || a.height >= this.cj.ys;
        }
        getDefaultTooltipTemplate() {
            let a = "<div class='ui-chart-default-tooltip-content'><span";
            let b = this.f.ba.a$u(this.f);
            if (!stringIsNullOrEmpty(b)) {
                a += " style='color:" + b + "'";
            }
            a += ">" + this.cj.title + "</span><br/>";
            a += "</div>";
            return a;
        }
    }
    ScatterPolylineSeriesView.$t = markType(ScatterPolylineSeriesView, 'ScatterPolylineSeriesView', ShapeSeriesViewBase.$);
    return ScatterPolylineSeriesView;
})();
